@@ -14,11 +14,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.003002
+Version 0.003003
 
 =cut
 
-our $VERSION = '0.003002';
+our $VERSION = '0.003003';
 
 # Dependencies
 use parent 'Exporter::Tiny';
@@ -138,7 +138,7 @@ my $years_re    = qr/$yearspan_re(?:$comma_re$yearspan_re)*/;
 my $owners_re   = qr/$owner_prefix_re*$owner_initial_re\S*(?:$blank_re*\S+)*/;
 
 my $signs_and_more_re
-	= qr/(?:$chatter_re.*|$signs_re(?::$blank_or_break_re|$comma_re)($years_re?$comma_re?$owner_intro_re?$owners_re?)|(?:\n|\z))/s;
+	= qr/(?:$chatter_re.*|$signs_re(?::$blank_or_break_re|$comma_re)($years_re?$comma_re?$owner_intro_re?$owners_re?)|(?:\n|\z))/;
 
 sub _generate_copyright
 {
